@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Bugs::DefaultRT;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -9,10 +9,6 @@ use Moose;
 with 'Pod::Weaver::Role::Section';
 with 'Pod::Weaver::Role::AddTextToSection';
 
-#use Log::Any '$log';
-
-use List::Util qw(first);
-
 sub weave_section {
   my ($self, $document, $input) = @_;
 
@@ -47,6 +43,8 @@ patch to an existing test-file that illustrates the bug or desired
 feature.
 HERE
 
+  $text .= "\n\n";
+
   $self->add_text_to_section($document, $text, 'BUGS',
                              {ignore=>1});
 }
@@ -67,7 +65,7 @@ Pod::Weaver::Section::Bugs::DefaultRT - Add a BUGS section to refer to bugtracke
 
 =head1 VERSION
 
-This document describes version 0.04 of Pod::Weaver::Section::Bugs::DefaultRT (from Perl distribution Pod-Weaver-Section-Bugs-DefaultRT), released on 2015-04-01.
+This document describes version 0.05 of Pod::Weaver::Section::Bugs::DefaultRT (from Perl distribution Pod-Weaver-Section-Bugs-DefaultRT), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -113,6 +111,7 @@ Please report any bugs or feature requests on the bugtracker website L<https://r
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
